# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TagSummary(object):
    """
    A tag definition that belongs to a specific tag namespace.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TagSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this TagSummary.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this TagSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this TagSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this TagSummary.
        :type description: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this TagSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this TagSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param is_retired:
            The value to assign to the is_retired property of this TagSummary.
        :type is_retired: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TagSummary.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this TagSummary.
        :type time_created: datetime

        :param is_cost_tracking:
            The value to assign to the is_cost_tracking property of this TagSummary.
        :type is_cost_tracking: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'is_retired': 'bool',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'is_cost_tracking': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'is_retired': 'isRetired',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'is_cost_tracking': 'isCostTracking'
        }

        self._compartment_id = None
        self._id = None
        self._name = None
        self._description = None
        self._freeform_tags = None
        self._defined_tags = None
        self._is_retired = None
        self._lifecycle_state = None
        self._time_created = None
        self._is_cost_tracking = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this TagSummary.
        The OCID of the compartment that contains the tag definition.


        :return: The compartment_id of this TagSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this TagSummary.
        The OCID of the compartment that contains the tag definition.


        :param compartment_id: The compartment_id of this TagSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        Gets the id of this TagSummary.
        The OCID of the tag definition.


        :return: The id of this TagSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TagSummary.
        The OCID of the tag definition.


        :param id: The id of this TagSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TagSummary.
        The name assigned to the tag during creation. This is the tag key definition.
        The name must be unique within the tag namespace and cannot be changed.


        :return: The name of this TagSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TagSummary.
        The name assigned to the tag during creation. This is the tag key definition.
        The name must be unique within the tag namespace and cannot be changed.


        :param name: The name of this TagSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TagSummary.
        The description you assign to the tag.


        :return: The description of this TagSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TagSummary.
        The description you assign to the tag.


        :param description: The description of this TagSummary.
        :type: str
        """
        self._description = description

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this TagSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this TagSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this TagSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this TagSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this TagSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this TagSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this TagSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this TagSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def is_retired(self):
        """
        Gets the is_retired of this TagSummary.
        Whether the tag is retired.
        See `Retiring Key Definitions and Namespace Definitions`__.

        __ https://docs.cloud.oracle.com/Content/Identity/Concepts/taggingoverview.htm#Retiring


        :return: The is_retired of this TagSummary.
        :rtype: bool
        """
        return self._is_retired

    @is_retired.setter
    def is_retired(self, is_retired):
        """
        Sets the is_retired of this TagSummary.
        Whether the tag is retired.
        See `Retiring Key Definitions and Namespace Definitions`__.

        __ https://docs.cloud.oracle.com/Content/Identity/Concepts/taggingoverview.htm#Retiring


        :param is_retired: The is_retired of this TagSummary.
        :type: bool
        """
        self._is_retired = is_retired

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TagSummary.
        The tag's current state. After creating a tag, make sure its `lifecycleState` is ACTIVE before using it. After retiring a tag, make sure its `lifecycleState` is INACTIVE before using it. If you delete a tag, you cannot delete another tag until the deleted tag's `lifecycleState` changes from DELETING to DELETED.


        :return: The lifecycle_state of this TagSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TagSummary.
        The tag's current state. After creating a tag, make sure its `lifecycleState` is ACTIVE before using it. After retiring a tag, make sure its `lifecycleState` is INACTIVE before using it. If you delete a tag, you cannot delete another tag until the deleted tag's `lifecycleState` changes from DELETING to DELETED.


        :param lifecycle_state: The lifecycle_state of this TagSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this TagSummary.
        Date and time the tag was created, in the format defined by RFC3339.
        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this TagSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this TagSummary.
        Date and time the tag was created, in the format defined by RFC3339.
        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this TagSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def is_cost_tracking(self):
        """
        Gets the is_cost_tracking of this TagSummary.
        Indicates whether the tag is enabled for cost tracking.


        :return: The is_cost_tracking of this TagSummary.
        :rtype: bool
        """
        return self._is_cost_tracking

    @is_cost_tracking.setter
    def is_cost_tracking(self, is_cost_tracking):
        """
        Sets the is_cost_tracking of this TagSummary.
        Indicates whether the tag is enabled for cost tracking.


        :param is_cost_tracking: The is_cost_tracking of this TagSummary.
        :type: bool
        """
        self._is_cost_tracking = is_cost_tracking

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerConfiguration(object):
    """
    Container configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_repository_created_on_first_push:
            The value to assign to the is_repository_created_on_first_push property of this ContainerConfiguration.
        :type is_repository_created_on_first_push: bool

        :param namespace:
            The value to assign to the namespace property of this ContainerConfiguration.
        :type namespace: str

        """
        self.swagger_types = {
            'is_repository_created_on_first_push': 'bool',
            'namespace': 'str'
        }

        self.attribute_map = {
            'is_repository_created_on_first_push': 'isRepositoryCreatedOnFirstPush',
            'namespace': 'namespace'
        }

        self._is_repository_created_on_first_push = None
        self._namespace = None

    @property
    def is_repository_created_on_first_push(self):
        """
        **[Required]** Gets the is_repository_created_on_first_push of this ContainerConfiguration.
        Whether to create a new container repository when a container is pushed to a new repository path.
        Repositories created in this way belong to the root compartment.


        :return: The is_repository_created_on_first_push of this ContainerConfiguration.
        :rtype: bool
        """
        return self._is_repository_created_on_first_push

    @is_repository_created_on_first_push.setter
    def is_repository_created_on_first_push(self, is_repository_created_on_first_push):
        """
        Sets the is_repository_created_on_first_push of this ContainerConfiguration.
        Whether to create a new container repository when a container is pushed to a new repository path.
        Repositories created in this way belong to the root compartment.


        :param is_repository_created_on_first_push: The is_repository_created_on_first_push of this ContainerConfiguration.
        :type: bool
        """
        self._is_repository_created_on_first_push = is_repository_created_on_first_push

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this ContainerConfiguration.
        The tenancy namespace used in the container repository path.


        :return: The namespace of this ContainerConfiguration.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this ContainerConfiguration.
        The tenancy namespace used in the container repository path.


        :param namespace: The namespace of this ContainerConfiguration.
        :type: str
        """
        self._namespace = namespace

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PeerRole(object):
    """
    Peer role
    """

    #: A constant which can be used with the role property of a PeerRole.
    #: This constant has a value of "MEMBER"
    ROLE_MEMBER = "MEMBER"

    #: A constant which can be used with the role property of a PeerRole.
    #: This constant has a value of "ADMIN"
    ROLE_ADMIN = "ADMIN"

    def __init__(self, **kwargs):
        """
        Initializes a new PeerRole object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param role:
            The value to assign to the role property of this PeerRole.
            Allowed values for this property are: "MEMBER", "ADMIN"
        :type role: str

        """
        self.swagger_types = {
            'role': 'str'
        }

        self.attribute_map = {
            'role': 'role'
        }

        self._role = None

    @property
    def role(self):
        """
        Gets the role of this PeerRole.
        Peer role names

        Allowed values for this property are: "MEMBER", "ADMIN"


        :return: The role of this PeerRole.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this PeerRole.
        Peer role names


        :param role: The role of this PeerRole.
        :type: str
        """
        allowed_values = ["MEMBER", "ADMIN"]
        if not value_allowed_none_or_none_sentinel(role, allowed_values):
            raise ValueError(
                "Invalid value for `role`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._role = role

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TraceSpanSummary(object):
    """
    Trace Span summary object is the summary of the span information for the spans in the span collection
    in the trace window that is being queried.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TraceSpanSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this TraceSpanSummary.
        :type key: str

        :param root_span_operation_name:
            The value to assign to the root_span_operation_name property of this TraceSpanSummary.
        :type root_span_operation_name: str

        :param time_earliest_span_started:
            The value to assign to the time_earliest_span_started property of this TraceSpanSummary.
        :type time_earliest_span_started: datetime

        :param time_latest_span_ended:
            The value to assign to the time_latest_span_ended property of this TraceSpanSummary.
        :type time_latest_span_ended: datetime

        :param span_count:
            The value to assign to the span_count property of this TraceSpanSummary.
        :type span_count: int

        :param error_span_count:
            The value to assign to the error_span_count property of this TraceSpanSummary.
        :type error_span_count: int

        :param root_span_service_name:
            The value to assign to the root_span_service_name property of this TraceSpanSummary.
        :type root_span_service_name: str

        :param time_root_span_started:
            The value to assign to the time_root_span_started property of this TraceSpanSummary.
        :type time_root_span_started: datetime

        :param time_root_span_ended:
            The value to assign to the time_root_span_ended property of this TraceSpanSummary.
        :type time_root_span_ended: datetime

        :param root_span_duration_in_ms:
            The value to assign to the root_span_duration_in_ms property of this TraceSpanSummary.
        :type root_span_duration_in_ms: int

        :param trace_duration_in_ms:
            The value to assign to the trace_duration_in_ms property of this TraceSpanSummary.
        :type trace_duration_in_ms: int

        :param is_fault:
            The value to assign to the is_fault property of this TraceSpanSummary.
        :type is_fault: bool

        :param trace_status:
            The value to assign to the trace_status property of this TraceSpanSummary.
        :type trace_status: str

        :param trace_error_type:
            The value to assign to the trace_error_type property of this TraceSpanSummary.
        :type trace_error_type: str

        :param trace_error_code:
            The value to assign to the trace_error_code property of this TraceSpanSummary.
        :type trace_error_code: str

        :param service_summaries:
            The value to assign to the service_summaries property of this TraceSpanSummary.
        :type service_summaries: list[oci.apm_traces.models.TraceServiceSummary]

        """
        self.swagger_types = {
            'key': 'str',
            'root_span_operation_name': 'str',
            'time_earliest_span_started': 'datetime',
            'time_latest_span_ended': 'datetime',
            'span_count': 'int',
            'error_span_count': 'int',
            'root_span_service_name': 'str',
            'time_root_span_started': 'datetime',
            'time_root_span_ended': 'datetime',
            'root_span_duration_in_ms': 'int',
            'trace_duration_in_ms': 'int',
            'is_fault': 'bool',
            'trace_status': 'str',
            'trace_error_type': 'str',
            'trace_error_code': 'str',
            'service_summaries': 'list[TraceServiceSummary]'
        }

        self.attribute_map = {
            'key': 'key',
            'root_span_operation_name': 'rootSpanOperationName',
            'time_earliest_span_started': 'timeEarliestSpanStarted',
            'time_latest_span_ended': 'timeLatestSpanEnded',
            'span_count': 'spanCount',
            'error_span_count': 'errorSpanCount',
            'root_span_service_name': 'rootSpanServiceName',
            'time_root_span_started': 'timeRootSpanStarted',
            'time_root_span_ended': 'timeRootSpanEnded',
            'root_span_duration_in_ms': 'rootSpanDurationInMs',
            'trace_duration_in_ms': 'traceDurationInMs',
            'is_fault': 'isFault',
            'trace_status': 'traceStatus',
            'trace_error_type': 'traceErrorType',
            'trace_error_code': 'traceErrorCode',
            'service_summaries': 'serviceSummaries'
        }

        self._key = None
        self._root_span_operation_name = None
        self._time_earliest_span_started = None
        self._time_latest_span_ended = None
        self._span_count = None
        self._error_span_count = None
        self._root_span_service_name = None
        self._time_root_span_started = None
        self._time_root_span_ended = None
        self._root_span_duration_in_ms = None
        self._trace_duration_in_ms = None
        self._is_fault = None
        self._trace_status = None
        self._trace_error_type = None
        self._trace_error_code = None
        self._service_summaries = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this TraceSpanSummary.
        Unique identifier (traceId) for the trace that represents the span set.  Note that this field is
        defined as traceKey in the API to comply with OCI API fields naming conventions.  The traceKey maps to
        the traceId in the APM repository.


        :return: The key of this TraceSpanSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TraceSpanSummary.
        Unique identifier (traceId) for the trace that represents the span set.  Note that this field is
        defined as traceKey in the API to comply with OCI API fields naming conventions.  The traceKey maps to
        the traceId in the APM repository.


        :param key: The key of this TraceSpanSummary.
        :type: str
        """
        self._key = key

    @property
    def root_span_operation_name(self):
        """
        Gets the root_span_operation_name of this TraceSpanSummary.
        Root span name associated with the trace. This is usually the flow start operation name.
        Null if the root span is not yet completed.


        :return: The root_span_operation_name of this TraceSpanSummary.
        :rtype: str
        """
        return self._root_span_operation_name

    @root_span_operation_name.setter
    def root_span_operation_name(self, root_span_operation_name):
        """
        Sets the root_span_operation_name of this TraceSpanSummary.
        Root span name associated with the trace. This is usually the flow start operation name.
        Null if the root span is not yet completed.


        :param root_span_operation_name: The root_span_operation_name of this TraceSpanSummary.
        :type: str
        """
        self._root_span_operation_name = root_span_operation_name

    @property
    def time_earliest_span_started(self):
        """
        **[Required]** Gets the time_earliest_span_started of this TraceSpanSummary.
        Start time of the earliest span in this span collection.


        :return: The time_earliest_span_started of this TraceSpanSummary.
        :rtype: datetime
        """
        return self._time_earliest_span_started

    @time_earliest_span_started.setter
    def time_earliest_span_started(self, time_earliest_span_started):
        """
        Sets the time_earliest_span_started of this TraceSpanSummary.
        Start time of the earliest span in this span collection.


        :param time_earliest_span_started: The time_earliest_span_started of this TraceSpanSummary.
        :type: datetime
        """
        self._time_earliest_span_started = time_earliest_span_started

    @property
    def time_latest_span_ended(self):
        """
        **[Required]** Gets the time_latest_span_ended of this TraceSpanSummary.
        End time of the span that most recently ended in this span collection.


        :return: The time_latest_span_ended of this TraceSpanSummary.
        :rtype: datetime
        """
        return self._time_latest_span_ended

    @time_latest_span_ended.setter
    def time_latest_span_ended(self, time_latest_span_ended):
        """
        Sets the time_latest_span_ended of this TraceSpanSummary.
        End time of the span that most recently ended in this span collection.


        :param time_latest_span_ended: The time_latest_span_ended of this TraceSpanSummary.
        :type: datetime
        """
        self._time_latest_span_ended = time_latest_span_ended

    @property
    def span_count(self):
        """
        **[Required]** Gets the span_count of this TraceSpanSummary.
        The number of spans that have been processed by the system for this trace.  Note that there
        could be additional spans that have not been processed or reported yet if the trace is still
        in progress.


        :return: The span_count of this TraceSpanSummary.
        :rtype: int
        """
        return self._span_count

    @span_count.setter
    def span_count(self, span_count):
        """
        Sets the span_count of this TraceSpanSummary.
        The number of spans that have been processed by the system for this trace.  Note that there
        could be additional spans that have not been processed or reported yet if the trace is still
        in progress.


        :param span_count: The span_count of this TraceSpanSummary.
        :type: int
        """
        self._span_count = span_count

    @property
    def error_span_count(self):
        """
        **[Required]** Gets the error_span_count of this TraceSpanSummary.
        The number of spans with error that have been processed by the system for this trace.
        Note that the number of spans with errors may be less than the total number of actual spans
        in this trace.


        :return: The error_span_count of this TraceSpanSummary.
        :rtype: int
        """
        return self._error_span_count

    @error_span_count.setter
    def error_span_count(self, error_span_count):
        """
        Sets the error_span_count of this TraceSpanSummary.
        The number of spans with error that have been processed by the system for this trace.
        Note that the number of spans with errors may be less than the total number of actual spans
        in this trace.


        :param error_span_count: The error_span_count of this TraceSpanSummary.
        :type: int
        """
        self._error_span_count = error_span_count

    @property
    def root_span_service_name(self):
        """
        Gets the root_span_service_name of this TraceSpanSummary.
        Service associated with this trace.


        :return: The root_span_service_name of this TraceSpanSummary.
        :rtype: str
        """
        return self._root_span_service_name

    @root_span_service_name.setter
    def root_span_service_name(self, root_span_service_name):
        """
        Sets the root_span_service_name of this TraceSpanSummary.
        Service associated with this trace.


        :param root_span_service_name: The root_span_service_name of this TraceSpanSummary.
        :type: str
        """
        self._root_span_service_name = root_span_service_name

    @property
    def time_root_span_started(self):
        """
        Gets the time_root_span_started of this TraceSpanSummary.
        Start time of the root span for this span collection.


        :return: The time_root_span_started of this TraceSpanSummary.
        :rtype: datetime
        """
        return self._time_root_span_started

    @time_root_span_started.setter
    def time_root_span_started(self, time_root_span_started):
        """
        Sets the time_root_span_started of this TraceSpanSummary.
        Start time of the root span for this span collection.


        :param time_root_span_started: The time_root_span_started of this TraceSpanSummary.
        :type: datetime
        """
        self._time_root_span_started = time_root_span_started

    @property
    def time_root_span_ended(self):
        """
        Gets the time_root_span_ended of this TraceSpanSummary.
        End time of the root span for this span collection.


        :return: The time_root_span_ended of this TraceSpanSummary.
        :rtype: datetime
        """
        return self._time_root_span_ended

    @time_root_span_ended.setter
    def time_root_span_ended(self, time_root_span_ended):
        """
        Sets the time_root_span_ended of this TraceSpanSummary.
        End time of the root span for this span collection.


        :param time_root_span_ended: The time_root_span_ended of this TraceSpanSummary.
        :type: datetime
        """
        self._time_root_span_ended = time_root_span_ended

    @property
    def root_span_duration_in_ms(self):
        """
        Gets the root_span_duration_in_ms of this TraceSpanSummary.
        Time taken for the root span operation to complete in milliseconds.


        :return: The root_span_duration_in_ms of this TraceSpanSummary.
        :rtype: int
        """
        return self._root_span_duration_in_ms

    @root_span_duration_in_ms.setter
    def root_span_duration_in_ms(self, root_span_duration_in_ms):
        """
        Sets the root_span_duration_in_ms of this TraceSpanSummary.
        Time taken for the root span operation to complete in milliseconds.


        :param root_span_duration_in_ms: The root_span_duration_in_ms of this TraceSpanSummary.
        :type: int
        """
        self._root_span_duration_in_ms = root_span_duration_in_ms

    @property
    def trace_duration_in_ms(self):
        """
        **[Required]** Gets the trace_duration_in_ms of this TraceSpanSummary.
        Time between the start of the earliest span and the end of the most recent span in milliseconds.


        :return: The trace_duration_in_ms of this TraceSpanSummary.
        :rtype: int
        """
        return self._trace_duration_in_ms

    @trace_duration_in_ms.setter
    def trace_duration_in_ms(self, trace_duration_in_ms):
        """
        Sets the trace_duration_in_ms of this TraceSpanSummary.
        Time between the start of the earliest span and the end of the most recent span in milliseconds.


        :param trace_duration_in_ms: The trace_duration_in_ms of this TraceSpanSummary.
        :type: int
        """
        self._trace_duration_in_ms = trace_duration_in_ms

    @property
    def is_fault(self):
        """
        **[Required]** Gets the is_fault of this TraceSpanSummary.
        Boolean flag that indicates whether the trace errored out.


        :return: The is_fault of this TraceSpanSummary.
        :rtype: bool
        """
        return self._is_fault

    @is_fault.setter
    def is_fault(self, is_fault):
        """
        Sets the is_fault of this TraceSpanSummary.
        Boolean flag that indicates whether the trace errored out.


        :param is_fault: The is_fault of this TraceSpanSummary.
        :type: bool
        """
        self._is_fault = is_fault

    @property
    def trace_status(self):
        """
        **[Required]** Gets the trace_status of this TraceSpanSummary.
        The status of the trace.
        The trace statuses are defined as follows:
        complete \u2013 a root span has been recorded, but there is no information on the errors.
        success - a complete root span is recorded there is a successful error type and error code - HTTP 200.
        incomplete - the root span has not yet been received.
        error - the root span returned with an error. There may or may not be an associated error code or error type.


        :return: The trace_status of this TraceSpanSummary.
        :rtype: str
        """
        return self._trace_status

    @trace_status.setter
    def trace_status(self, trace_status):
        """
        Sets the trace_status of this TraceSpanSummary.
        The status of the trace.
        The trace statuses are defined as follows:
        complete \u2013 a root span has been recorded, but there is no information on the errors.
        success - a complete root span is recorded there is a successful error type and error code - HTTP 200.
        incomplete - the root span has not yet been received.
        error - the root span returned with an error. There may or may not be an associated error code or error type.


        :param trace_status: The trace_status of this TraceSpanSummary.
        :type: str
        """
        self._trace_status = trace_status

    @property
    def trace_error_type(self):
        """
        **[Required]** Gets the trace_error_type of this TraceSpanSummary.
        Error type of the trace.


        :return: The trace_error_type of this TraceSpanSummary.
        :rtype: str
        """
        return self._trace_error_type

    @trace_error_type.setter
    def trace_error_type(self, trace_error_type):
        """
        Sets the trace_error_type of this TraceSpanSummary.
        Error type of the trace.


        :param trace_error_type: The trace_error_type of this TraceSpanSummary.
        :type: str
        """
        self._trace_error_type = trace_error_type

    @property
    def trace_error_code(self):
        """
        **[Required]** Gets the trace_error_code of this TraceSpanSummary.
        Error code of the trace.


        :return: The trace_error_code of this TraceSpanSummary.
        :rtype: str
        """
        return self._trace_error_code

    @trace_error_code.setter
    def trace_error_code(self, trace_error_code):
        """
        Sets the trace_error_code of this TraceSpanSummary.
        Error code of the trace.


        :param trace_error_code: The trace_error_code of this TraceSpanSummary.
        :type: str
        """
        self._trace_error_code = trace_error_code

    @property
    def service_summaries(self):
        """
        Gets the service_summaries of this TraceSpanSummary.
        A summary of the spans by service


        :return: The service_summaries of this TraceSpanSummary.
        :rtype: list[oci.apm_traces.models.TraceServiceSummary]
        """
        return self._service_summaries

    @service_summaries.setter
    def service_summaries(self, service_summaries):
        """
        Sets the service_summaries of this TraceSpanSummary.
        A summary of the spans by service


        :param service_summaries: The service_summaries of this TraceSpanSummary.
        :type: list[oci.apm_traces.models.TraceServiceSummary]
        """
        self._service_summaries = service_summaries

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .category_log_details import CategoryLogDetails
from .change_job_compartment_details import ChangeJobCompartmentDetails
from .change_job_run_compartment_details import ChangeJobRunCompartmentDetails
from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_model_deployment_compartment_details import ChangeModelDeploymentCompartmentDetails
from .change_notebook_session_compartment_details import ChangeNotebookSessionCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .create_job_details import CreateJobDetails
from .create_job_run_details import CreateJobRunDetails
from .create_model_deployment_details import CreateModelDeploymentDetails
from .create_model_details import CreateModelDetails
from .create_model_provenance_details import CreateModelProvenanceDetails
from .create_notebook_session_details import CreateNotebookSessionDetails
from .create_project_details import CreateProjectDetails
from .default_job_configuration_details import DefaultJobConfigurationDetails
from .fixed_size_scaling_policy import FixedSizeScalingPolicy
from .instance_configuration import InstanceConfiguration
from .job import Job
from .job_configuration_details import JobConfigurationDetails
from .job_infrastructure_configuration_details import JobInfrastructureConfigurationDetails
from .job_log_configuration_details import JobLogConfigurationDetails
from .job_run import JobRun
from .job_run_log_details import JobRunLogDetails
from .job_run_summary import JobRunSummary
from .job_shape_summary import JobShapeSummary
from .job_summary import JobSummary
from .log_details import LogDetails
from .metadata import Metadata
from .model import Model
from .model_configuration_details import ModelConfigurationDetails
from .model_deployment import ModelDeployment
from .model_deployment_configuration_details import ModelDeploymentConfigurationDetails
from .model_deployment_shape_summary import ModelDeploymentShapeSummary
from .model_deployment_summary import ModelDeploymentSummary
from .model_provenance import ModelProvenance
from .model_summary import ModelSummary
from .notebook_session import NotebookSession
from .notebook_session_configuration_details import NotebookSessionConfigurationDetails
from .notebook_session_shape_config_details import NotebookSessionShapeConfigDetails
from .notebook_session_shape_summary import NotebookSessionShapeSummary
from .notebook_session_summary import NotebookSessionSummary
from .project import Project
from .project_summary import ProjectSummary
from .scaling_policy import ScalingPolicy
from .single_model_deployment_configuration_details import SingleModelDeploymentConfigurationDetails
from .standalone_job_infrastructure_configuration_details import StandaloneJobInfrastructureConfigurationDetails
from .update_category_log_details import UpdateCategoryLogDetails
from .update_job_details import UpdateJobDetails
from .update_job_run_details import UpdateJobRunDetails
from .update_model_configuration_details import UpdateModelConfigurationDetails
from .update_model_deployment_configuration_details import UpdateModelDeploymentConfigurationDetails
from .update_model_deployment_details import UpdateModelDeploymentDetails
from .update_model_details import UpdateModelDetails
from .update_model_provenance_details import UpdateModelProvenanceDetails
from .update_notebook_session_details import UpdateNotebookSessionDetails
from .update_project_details import UpdateProjectDetails
from .update_single_model_deployment_configuration_details import UpdateSingleModelDeploymentConfigurationDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for data_science services.
data_science_type_mapping = {
    "CategoryLogDetails": CategoryLogDetails,
    "ChangeJobCompartmentDetails": ChangeJobCompartmentDetails,
    "ChangeJobRunCompartmentDetails": ChangeJobRunCompartmentDetails,
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeModelDeploymentCompartmentDetails": ChangeModelDeploymentCompartmentDetails,
    "ChangeNotebookSessionCompartmentDetails": ChangeNotebookSessionCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "CreateJobDetails": CreateJobDetails,
    "CreateJobRunDetails": CreateJobRunDetails,
    "CreateModelDeploymentDetails": CreateModelDeploymentDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateModelProvenanceDetails": CreateModelProvenanceDetails,
    "CreateNotebookSessionDetails": CreateNotebookSessionDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "DefaultJobConfigurationDetails": DefaultJobConfigurationDetails,
    "FixedSizeScalingPolicy": FixedSizeScalingPolicy,
    "InstanceConfiguration": InstanceConfiguration,
    "Job": Job,
    "JobConfigurationDetails": JobConfigurationDetails,
    "JobInfrastructureConfigurationDetails": JobInfrastructureConfigurationDetails,
    "JobLogConfigurationDetails": JobLogConfigurationDetails,
    "JobRun": JobRun,
    "JobRunLogDetails": JobRunLogDetails,
    "JobRunSummary": JobRunSummary,
    "JobShapeSummary": JobShapeSummary,
    "JobSummary": JobSummary,
    "LogDetails": LogDetails,
    "Metadata": Metadata,
    "Model": Model,
    "ModelConfigurationDetails": ModelConfigurationDetails,
    "ModelDeployment": ModelDeployment,
    "ModelDeploymentConfigurationDetails": ModelDeploymentConfigurationDetails,
    "ModelDeploymentShapeSummary": ModelDeploymentShapeSummary,
    "ModelDeploymentSummary": ModelDeploymentSummary,
    "ModelProvenance": ModelProvenance,
    "ModelSummary": ModelSummary,
    "NotebookSession": NotebookSession,
    "NotebookSessionConfigurationDetails": NotebookSessionConfigurationDetails,
    "NotebookSessionShapeConfigDetails": NotebookSessionShapeConfigDetails,
    "NotebookSessionShapeSummary": NotebookSessionShapeSummary,
    "NotebookSessionSummary": NotebookSessionSummary,
    "Project": Project,
    "ProjectSummary": ProjectSummary,
    "ScalingPolicy": ScalingPolicy,
    "SingleModelDeploymentConfigurationDetails": SingleModelDeploymentConfigurationDetails,
    "StandaloneJobInfrastructureConfigurationDetails": StandaloneJobInfrastructureConfigurationDetails,
    "UpdateCategoryLogDetails": UpdateCategoryLogDetails,
    "UpdateJobDetails": UpdateJobDetails,
    "UpdateJobRunDetails": UpdateJobRunDetails,
    "UpdateModelConfigurationDetails": UpdateModelConfigurationDetails,
    "UpdateModelDeploymentConfigurationDetails": UpdateModelDeploymentConfigurationDetails,
    "UpdateModelDeploymentDetails": UpdateModelDeploymentDetails,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateModelProvenanceDetails": UpdateModelProvenanceDetails,
    "UpdateNotebookSessionDetails": UpdateNotebookSessionDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateSingleModelDeploymentConfigurationDetails": UpdateSingleModelDeploymentConfigurationDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NotebookSessionShapeSummary(object):
    """
    The compute shape used to launch a notebook session compute instance.
    """

    #: A constant which can be used with the shape_series property of a NotebookSessionShapeSummary.
    #: This constant has a value of "AMD_ROME"
    SHAPE_SERIES_AMD_ROME = "AMD_ROME"

    #: A constant which can be used with the shape_series property of a NotebookSessionShapeSummary.
    #: This constant has a value of "INTEL_SKYLAKE"
    SHAPE_SERIES_INTEL_SKYLAKE = "INTEL_SKYLAKE"

    #: A constant which can be used with the shape_series property of a NotebookSessionShapeSummary.
    #: This constant has a value of "NVIDIA_GPU"
    SHAPE_SERIES_NVIDIA_GPU = "NVIDIA_GPU"

    #: A constant which can be used with the shape_series property of a NotebookSessionShapeSummary.
    #: This constant has a value of "LEGACY"
    SHAPE_SERIES_LEGACY = "LEGACY"

    def __init__(self, **kwargs):
        """
        Initializes a new NotebookSessionShapeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this NotebookSessionShapeSummary.
        :type name: str

        :param core_count:
            The value to assign to the core_count property of this NotebookSessionShapeSummary.
        :type core_count: int

        :param memory_in_gbs:
            The value to assign to the memory_in_gbs property of this NotebookSessionShapeSummary.
        :type memory_in_gbs: int

        :param shape_series:
            The value to assign to the shape_series property of this NotebookSessionShapeSummary.
            Allowed values for this property are: "AMD_ROME", "INTEL_SKYLAKE", "NVIDIA_GPU", "LEGACY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shape_series: str

        """
        self.swagger_types = {
            'name': 'str',
            'core_count': 'int',
            'memory_in_gbs': 'int',
            'shape_series': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'core_count': 'coreCount',
            'memory_in_gbs': 'memoryInGBs',
            'shape_series': 'shapeSeries'
        }

        self._name = None
        self._core_count = None
        self._memory_in_gbs = None
        self._shape_series = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this NotebookSessionShapeSummary.
        The name of the notebook session shape.


        :return: The name of this NotebookSessionShapeSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NotebookSessionShapeSummary.
        The name of the notebook session shape.


        :param name: The name of this NotebookSessionShapeSummary.
        :type: str
        """
        self._name = name

    @property
    def core_count(self):
        """
        **[Required]** Gets the core_count of this NotebookSessionShapeSummary.
        The number of cores associated with this notebook session shape.


        :return: The core_count of this NotebookSessionShapeSummary.
        :rtype: int
        """
        return self._core_count

    @core_count.setter
    def core_count(self, core_count):
        """
        Sets the core_count of this NotebookSessionShapeSummary.
        The number of cores associated with this notebook session shape.


        :param core_count: The core_count of this NotebookSessionShapeSummary.
        :type: int
        """
        self._core_count = core_count

    @property
    def memory_in_gbs(self):
        """
        **[Required]** Gets the memory_in_gbs of this NotebookSessionShapeSummary.
        The amount of memory in GBs associated with this notebook session shape.


        :return: The memory_in_gbs of this NotebookSessionShapeSummary.
        :rtype: int
        """
        return self._memory_in_gbs

    @memory_in_gbs.setter
    def memory_in_gbs(self, memory_in_gbs):
        """
        Sets the memory_in_gbs of this NotebookSessionShapeSummary.
        The amount of memory in GBs associated with this notebook session shape.


        :param memory_in_gbs: The memory_in_gbs of this NotebookSessionShapeSummary.
        :type: int
        """
        self._memory_in_gbs = memory_in_gbs

    @property
    def shape_series(self):
        """
        **[Required]** Gets the shape_series of this NotebookSessionShapeSummary.
        The family that the compute shape belongs to.

        Allowed values for this property are: "AMD_ROME", "INTEL_SKYLAKE", "NVIDIA_GPU", "LEGACY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shape_series of this NotebookSessionShapeSummary.
        :rtype: str
        """
        return self._shape_series

    @shape_series.setter
    def shape_series(self, shape_series):
        """
        Sets the shape_series of this NotebookSessionShapeSummary.
        The family that the compute shape belongs to.


        :param shape_series: The shape_series of this NotebookSessionShapeSummary.
        :type: str
        """
        allowed_values = ["AMD_ROME", "INTEL_SKYLAKE", "NVIDIA_GPU", "LEGACY"]
        if not value_allowed_none_or_none_sentinel(shape_series, allowed_values):
            shape_series = 'UNKNOWN_ENUM_VALUE'
        self._shape_series = shape_series

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateClusterDetails(object):
    """
    The properties that define a request to update a cluster.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UpdateClusterDetails.
        :type name: str

        :param kubernetes_version:
            The value to assign to the kubernetes_version property of this UpdateClusterDetails.
        :type kubernetes_version: str

        :param options:
            The value to assign to the options property of this UpdateClusterDetails.
        :type options: oci.container_engine.models.UpdateClusterOptionsDetails

        :param image_policy_config:
            The value to assign to the image_policy_config property of this UpdateClusterDetails.
        :type image_policy_config: oci.container_engine.models.UpdateImagePolicyConfigDetails

        """
        self.swagger_types = {
            'name': 'str',
            'kubernetes_version': 'str',
            'options': 'UpdateClusterOptionsDetails',
            'image_policy_config': 'UpdateImagePolicyConfigDetails'
        }

        self.attribute_map = {
            'name': 'name',
            'kubernetes_version': 'kubernetesVersion',
            'options': 'options',
            'image_policy_config': 'imagePolicyConfig'
        }

        self._name = None
        self._kubernetes_version = None
        self._options = None
        self._image_policy_config = None

    @property
    def name(self):
        """
        Gets the name of this UpdateClusterDetails.
        The new name for the cluster. Avoid entering confidential information.


        :return: The name of this UpdateClusterDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateClusterDetails.
        The new name for the cluster. Avoid entering confidential information.


        :param name: The name of this UpdateClusterDetails.
        :type: str
        """
        self._name = name

    @property
    def kubernetes_version(self):
        """
        Gets the kubernetes_version of this UpdateClusterDetails.
        The version of Kubernetes to which the cluster masters should be upgraded.


        :return: The kubernetes_version of this UpdateClusterDetails.
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """
        Sets the kubernetes_version of this UpdateClusterDetails.
        The version of Kubernetes to which the cluster masters should be upgraded.


        :param kubernetes_version: The kubernetes_version of this UpdateClusterDetails.
        :type: str
        """
        self._kubernetes_version = kubernetes_version

    @property
    def options(self):
        """
        Gets the options of this UpdateClusterDetails.

        :return: The options of this UpdateClusterDetails.
        :rtype: oci.container_engine.models.UpdateClusterOptionsDetails
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this UpdateClusterDetails.

        :param options: The options of this UpdateClusterDetails.
        :type: oci.container_engine.models.UpdateClusterOptionsDetails
        """
        self._options = options

    @property
    def image_policy_config(self):
        """
        Gets the image_policy_config of this UpdateClusterDetails.
        The image verification policy for signature validation. Once a policy is created and enabled with
        one or more kms keys, the policy will ensure all images deployed has been signed with the key(s)
        attached to the policy.


        :return: The image_policy_config of this UpdateClusterDetails.
        :rtype: oci.container_engine.models.UpdateImagePolicyConfigDetails
        """
        return self._image_policy_config

    @image_policy_config.setter
    def image_policy_config(self, image_policy_config):
        """
        Sets the image_policy_config of this UpdateClusterDetails.
        The image verification policy for signature validation. Once a policy is created and enabled with
        one or more kms keys, the policy will ensure all images deployed has been signed with the key(s)
        attached to the policy.


        :param image_policy_config: The image_policy_config of this UpdateClusterDetails.
        :type: oci.container_engine.models.UpdateImagePolicyConfigDetails
        """
        self._image_policy_config = image_policy_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DedicatedVmHostSummary(object):
    """
    A dedicated virtual machine (VM) host lets you host multiple instances on a dedicated server that is not shared with other tenancies.
    """

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DedicatedVmHostSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DedicatedVmHostSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this DedicatedVmHostSummary.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DedicatedVmHostSummary.
        :type compartment_id: str

        :param dedicated_vm_host_shape:
            The value to assign to the dedicated_vm_host_shape property of this DedicatedVmHostSummary.
        :type dedicated_vm_host_shape: str

        :param display_name:
            The value to assign to the display_name property of this DedicatedVmHostSummary.
        :type display_name: str

        :param fault_domain:
            The value to assign to the fault_domain property of this DedicatedVmHostSummary.
        :type fault_domain: str

        :param id:
            The value to assign to the id property of this DedicatedVmHostSummary.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DedicatedVmHostSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this DedicatedVmHostSummary.
        :type time_created: datetime

        :param remaining_ocpus:
            The value to assign to the remaining_ocpus property of this DedicatedVmHostSummary.
        :type remaining_ocpus: float

        :param total_ocpus:
            The value to assign to the total_ocpus property of this DedicatedVmHostSummary.
        :type total_ocpus: float

        :param total_memory_in_gbs:
            The value to assign to the total_memory_in_gbs property of this DedicatedVmHostSummary.
        :type total_memory_in_gbs: float

        :param remaining_memory_in_gbs:
            The value to assign to the remaining_memory_in_gbs property of this DedicatedVmHostSummary.
        :type remaining_memory_in_gbs: float

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'dedicated_vm_host_shape': 'str',
            'display_name': 'str',
            'fault_domain': 'str',
            'id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'remaining_ocpus': 'float',
            'total_ocpus': 'float',
            'total_memory_in_gbs': 'float',
            'remaining_memory_in_gbs': 'float'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'dedicated_vm_host_shape': 'dedicatedVmHostShape',
            'display_name': 'displayName',
            'fault_domain': 'faultDomain',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'remaining_ocpus': 'remainingOcpus',
            'total_ocpus': 'totalOcpus',
            'total_memory_in_gbs': 'totalMemoryInGBs',
            'remaining_memory_in_gbs': 'remainingMemoryInGBs'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._dedicated_vm_host_shape = None
        self._display_name = None
        self._fault_domain = None
        self._id = None
        self._lifecycle_state = None
        self._time_created = None
        self._remaining_ocpus = None
        self._total_ocpus = None
        self._total_memory_in_gbs = None
        self._remaining_memory_in_gbs = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this DedicatedVmHostSummary.
        The availability domain the dedicated VM host is running in.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DedicatedVmHostSummary.
        The availability domain the dedicated VM host is running in.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this DedicatedVmHostSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DedicatedVmHostSummary.
        The OCID of the compartment that contains the dedicated VM host.


        :return: The compartment_id of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DedicatedVmHostSummary.
        The OCID of the compartment that contains the dedicated VM host.


        :param compartment_id: The compartment_id of this DedicatedVmHostSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def dedicated_vm_host_shape(self):
        """
        **[Required]** Gets the dedicated_vm_host_shape of this DedicatedVmHostSummary.
        The shape of the dedicated VM host. The shape determines the number of CPUs and
        other resources available for VMs.


        :return: The dedicated_vm_host_shape of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._dedicated_vm_host_shape

    @dedicated_vm_host_shape.setter
    def dedicated_vm_host_shape(self, dedicated_vm_host_shape):
        """
        Sets the dedicated_vm_host_shape of this DedicatedVmHostSummary.
        The shape of the dedicated VM host. The shape determines the number of CPUs and
        other resources available for VMs.


        :param dedicated_vm_host_shape: The dedicated_vm_host_shape of this DedicatedVmHostSummary.
        :type: str
        """
        self._dedicated_vm_host_shape = dedicated_vm_host_shape

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DedicatedVmHostSummary.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My DVH`


        :return: The display_name of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DedicatedVmHostSummary.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My DVH`


        :param display_name: The display_name of this DedicatedVmHostSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this DedicatedVmHostSummary.
        The fault domain for the dedicated VM host's assigned instances. For more information, see Fault Domains.

        If you do not specify the fault domain, the system selects one for you. To change the fault domain for a dedicated VM host,
        delete it and create a new dedicated VM host in the preferred fault domain.

        To get a list of fault domains, use the ListFaultDomains operation in the Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :return: The fault_domain of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this DedicatedVmHostSummary.
        The fault domain for the dedicated VM host's assigned instances. For more information, see Fault Domains.

        If you do not specify the fault domain, the system selects one for you. To change the fault domain for a dedicated VM host,
        delete it and create a new dedicated VM host in the preferred fault domain.

        To get a list of fault domains, use the ListFaultDomains operation in the Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :param fault_domain: The fault_domain of this DedicatedVmHostSummary.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DedicatedVmHostSummary.
        The `OCID`__ of the dedicated VM host.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DedicatedVmHostSummary.
        The `OCID`__ of the dedicated VM host.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DedicatedVmHostSummary.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DedicatedVmHostSummary.
        The current state of the dedicated VM host.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DedicatedVmHostSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DedicatedVmHostSummary.
        The current state of the dedicated VM host.


        :param lifecycle_state: The lifecycle_state of this DedicatedVmHostSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DedicatedVmHostSummary.
        The date and time the dedicated VM host was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DedicatedVmHostSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DedicatedVmHostSummary.
        The date and time the dedicated VM host was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DedicatedVmHostSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def remaining_ocpus(self):
        """
        **[Required]** Gets the remaining_ocpus of this DedicatedVmHostSummary.
        The current available OCPUs of the dedicated VM host.


        :return: The remaining_ocpus of this DedicatedVmHostSummary.
        :rtype: float
        """
        return self._remaining_ocpus

    @remaining_ocpus.setter
    def remaining_ocpus(self, remaining_ocpus):
        """
        Sets the remaining_ocpus of this DedicatedVmHostSummary.
        The current available OCPUs of the dedicated VM host.


        :param remaining_ocpus: The remaining_ocpus of this DedicatedVmHostSummary.
        :type: float
        """
        self._remaining_ocpus = remaining_ocpus

    @property
    def total_ocpus(self):
        """
        **[Required]** Gets the total_ocpus of this DedicatedVmHostSummary.
        The current total OCPUs of the dedicated VM host.


        :return: The total_ocpus of this DedicatedVmHostSummary.
        :rtype: float
        """
        return self._total_ocpus

    @total_ocpus.setter
    def total_ocpus(self, total_ocpus):
        """
        Sets the total_ocpus of this DedicatedVmHostSummary.
        The current total OCPUs of the dedicated VM host.


        :param total_ocpus: The total_ocpus of this DedicatedVmHostSummary.
        :type: float
        """
        self._total_ocpus = total_ocpus

    @property
    def total_memory_in_gbs(self):
        """
        Gets the total_memory_in_gbs of this DedicatedVmHostSummary.
        The current total memory of the dedicated VM host, in GBs.


        :return: The total_memory_in_gbs of this DedicatedVmHostSummary.
        :rtype: float
        """
        return self._total_memory_in_gbs

    @total_memory_in_gbs.setter
    def total_memory_in_gbs(self, total_memory_in_gbs):
        """
        Sets the total_memory_in_gbs of this DedicatedVmHostSummary.
        The current total memory of the dedicated VM host, in GBs.


        :param total_memory_in_gbs: The total_memory_in_gbs of this DedicatedVmHostSummary.
        :type: float
        """
        self._total_memory_in_gbs = total_memory_in_gbs

    @property
    def remaining_memory_in_gbs(self):
        """
        Gets the remaining_memory_in_gbs of this DedicatedVmHostSummary.
        The current available memory of the dedicated VM host, in GBs.


        :return: The remaining_memory_in_gbs of this DedicatedVmHostSummary.
        :rtype: float
        """
        return self._remaining_memory_in_gbs

    @remaining_memory_in_gbs.setter
    def remaining_memory_in_gbs(self, remaining_memory_in_gbs):
        """
        Sets the remaining_memory_in_gbs of this DedicatedVmHostSummary.
        The current available memory of the dedicated VM host, in GBs.


        :param remaining_memory_in_gbs: The remaining_memory_in_gbs of this DedicatedVmHostSummary.
        :type: float
        """
        self._remaining_memory_in_gbs = remaining_memory_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateExadataInfrastructureDetails(object):
    """
    Request to create Exadata infrastructure resource. Applies to Exadata Cloud@Customer instances only.
    See :func:`create_cloud_exadata_infrastructure_details` for information on creating a cloud Exadata infrastructure resource in an Exadata Cloud Service instance.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateExadataInfrastructureDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateExadataInfrastructureDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateExadataInfrastructureDetails.
        :type display_name: str

        :param shape:
            The value to assign to the shape property of this CreateExadataInfrastructureDetails.
        :type shape: str

        :param time_zone:
            The value to assign to the time_zone property of this CreateExadataInfrastructureDetails.
        :type time_zone: str

        :param cloud_control_plane_server1:
            The value to assign to the cloud_control_plane_server1 property of this CreateExadataInfrastructureDetails.
        :type cloud_control_plane_server1: str

        :param cloud_control_plane_server2:
            The value to assign to the cloud_control_plane_server2 property of this CreateExadataInfrastructureDetails.
        :type cloud_control_plane_server2: str

        :param netmask:
            The value to assign to the netmask property of this CreateExadataInfrastructureDetails.
        :type netmask: str

        :param gateway:
            The value to assign to the gateway property of this CreateExadataInfrastructureDetails.
        :type gateway: str

        :param admin_network_cidr:
            The value to assign to the admin_network_cidr property of this CreateExadataInfrastructureDetails.
        :type admin_network_cidr: str

        :param infini_band_network_cidr:
            The value to assign to the infini_band_network_cidr property of this CreateExadataInfrastructureDetails.
        :type infini_band_network_cidr: str

        :param corporate_proxy:
            The value to assign to the corporate_proxy property of this CreateExadataInfrastructureDetails.
        :type corporate_proxy: str

        :param contacts:
            The value to assign to the contacts property of this CreateExadataInfrastructureDetails.
        :type contacts: list[oci.database.models.ExadataInfrastructureContact]

        :param maintenance_window:
            The value to assign to the maintenance_window property of this CreateExadataInfrastructureDetails.
        :type maintenance_window: oci.database.models.MaintenanceWindow

        :param storage_count:
            The value to assign to the storage_count property of this CreateExadataInfrastructureDetails.
        :type storage_count: int

        :param compute_count:
            The value to assign to the compute_count property of this CreateExadataInfrastructureDetails.
        :type compute_count: int

        :param dns_server:
            The value to assign to the dns_server property of this CreateExadataInfrastructureDetails.
        :type dns_server: list[str]

        :param ntp_server:
            The value to assign to the ntp_server property of this CreateExadataInfrastructureDetails.
        :type ntp_server: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateExadataInfrastructureDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateExadataInfrastructureDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'shape': 'str',
            'time_zone': 'str',
            'cloud_control_plane_server1': 'str',
            'cloud_control_plane_server2': 'str',
            'netmask': 'str',
            'gateway': 'str',
            'admin_network_cidr': 'str',
            'infini_band_network_cidr': 'str',
            'corporate_proxy': 'str',
            'contacts': 'list[ExadataInfrastructureContact]',
            'maintenance_window': 'MaintenanceWindow',
            'storage_count': 'int',
            'compute_count': 'int',
            'dns_server': 'list[str]',
            'ntp_server': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'shape': 'shape',
            'time_zone': 'timeZone',
            'cloud_control_plane_server1': 'cloudControlPlaneServer1',
            'cloud_control_plane_server2': 'cloudControlPlaneServer2',
            'netmask': 'netmask',
            'gateway': 'gateway',
            'admin_network_cidr': 'adminNetworkCIDR',
            'infini_band_network_cidr': 'infiniBandNetworkCIDR',
            'corporate_proxy': 'corporateProxy',
            'contacts': 'contacts',
            'maintenance_window': 'maintenanceWindow',
            'storage_count': 'storageCount',
            'compute_count': 'computeCount',
            'dns_server': 'dnsServer',
            'ntp_server': 'ntpServer',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._shape = None
        self._time_zone = None
        self._cloud_control_plane_server1 = None
        self._cloud_control_plane_server2 = None
        self._netmask = None
        self._gateway = None
        self._admin_network_cidr = None
        self._infini_band_network_cidr = None
        self._corporate_proxy = None
        self._contacts = None
        self._maintenance_window = None
        self._storage_count = None
        self._compute_count = None
        self._dns_server = None
        self._ntp_server = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateExadataInfrastructureDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateExadataInfrastructureDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateExadataInfrastructureDetails.
        The user-friendly name for the Exadata infrastructure. The name does not need to be unique.


        :return: The display_name of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateExadataInfrastructureDetails.
        The user-friendly name for the Exadata infrastructure. The name does not need to be unique.


        :param display_name: The display_name of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this CreateExadataInfrastructureDetails.
        The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.


        :return: The shape of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CreateExadataInfrastructureDetails.
        The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.


        :param shape: The shape of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._shape = shape

    @property
    def time_zone(self):
        """
        **[Required]** Gets the time_zone of this CreateExadataInfrastructureDetails.
        The time zone of the Exadata infrastructure. For details, see `Exadata Infrastructure Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this CreateExadataInfrastructureDetails.
        The time zone of the Exadata infrastructure. For details, see `Exadata Infrastructure Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def cloud_control_plane_server1(self):
        """
        **[Required]** Gets the cloud_control_plane_server1 of this CreateExadataInfrastructureDetails.
        The IP address for the first control plane server.


        :return: The cloud_control_plane_server1 of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._cloud_control_plane_server1

    @cloud_control_plane_server1.setter
    def cloud_control_plane_server1(self, cloud_control_plane_server1):
        """
        Sets the cloud_control_plane_server1 of this CreateExadataInfrastructureDetails.
        The IP address for the first control plane server.


        :param cloud_control_plane_server1: The cloud_control_plane_server1 of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._cloud_control_plane_server1 = cloud_control_plane_server1

    @property
    def cloud_control_plane_server2(self):
        """
        **[Required]** Gets the cloud_control_plane_server2 of this CreateExadataInfrastructureDetails.
        The IP address for the second control plane server.


        :return: The cloud_control_plane_server2 of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._cloud_control_plane_server2

    @cloud_control_plane_server2.setter
    def cloud_control_plane_server2(self, cloud_control_plane_server2):
        """
        Sets the cloud_control_plane_server2 of this CreateExadataInfrastructureDetails.
        The IP address for the second control plane server.


        :param cloud_control_plane_server2: The cloud_control_plane_server2 of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._cloud_control_plane_server2 = cloud_control_plane_server2

    @property
    def netmask(self):
        """
        **[Required]** Gets the netmask of this CreateExadataInfrastructureDetails.
        The netmask for the control plane network.


        :return: The netmask of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """
        Sets the netmask of this CreateExadataInfrastructureDetails.
        The netmask for the control plane network.


        :param netmask: The netmask of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._netmask = netmask

    @property
    def gateway(self):
        """
        **[Required]** Gets the gateway of this CreateExadataInfrastructureDetails.
        The gateway for the control plane network.


        :return: The gateway of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """
        Sets the gateway of this CreateExadataInfrastructureDetails.
        The gateway for the control plane network.


        :param gateway: The gateway of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._gateway = gateway

    @property
    def admin_network_cidr(self):
        """
        **[Required]** Gets the admin_network_cidr of this CreateExadataInfrastructureDetails.
        The CIDR block for the Exadata administration network.


        :return: The admin_network_cidr of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._admin_network_cidr

    @admin_network_cidr.setter
    def admin_network_cidr(self, admin_network_cidr):
        """
        Sets the admin_network_cidr of this CreateExadataInfrastructureDetails.
        The CIDR block for the Exadata administration network.


        :param admin_network_cidr: The admin_network_cidr of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._admin_network_cidr = admin_network_cidr

    @property
    def infini_band_network_cidr(self):
        """
        **[Required]** Gets the infini_band_network_cidr of this CreateExadataInfrastructureDetails.
        The CIDR block for the Exadata InfiniBand interconnect.


        :return: The infini_band_network_cidr of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._infini_band_network_cidr

    @infini_band_network_cidr.setter
    def infini_band_network_cidr(self, infini_band_network_cidr):
        """
        Sets the infini_band_network_cidr of this CreateExadataInfrastructureDetails.
        The CIDR block for the Exadata InfiniBand interconnect.


        :param infini_band_network_cidr: The infini_band_network_cidr of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._infini_band_network_cidr = infini_band_network_cidr

    @property
    def corporate_proxy(self):
        """
        Gets the corporate_proxy of this CreateExadataInfrastructureDetails.
        The corporate network proxy for access to the control plane network. Oracle recommends using an HTTPS proxy when possible
        for enhanced security.


        :return: The corporate_proxy of this CreateExadataInfrastructureDetails.
        :rtype: str
        """
        return self._corporate_proxy

    @corporate_proxy.setter
    def corporate_proxy(self, corporate_proxy):
        """
        Sets the corporate_proxy of this CreateExadataInfrastructureDetails.
        The corporate network proxy for access to the control plane network. Oracle recommends using an HTTPS proxy when possible
        for enhanced security.


        :param corporate_proxy: The corporate_proxy of this CreateExadataInfrastructureDetails.
        :type: str
        """
        self._corporate_proxy = corporate_proxy

    @property
    def contacts(self):
        """
        Gets the contacts of this CreateExadataInfrastructureDetails.
        The list of contacts for the Exadata infrastructure.


        :return: The contacts of this CreateExadataInfrastructureDetails.
        :rtype: list[oci.database.models.ExadataInfrastructureContact]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """
        Sets the contacts of this CreateExadataInfrastructureDetails.
        The list of contacts for the Exadata infrastructure.


        :param contacts: The contacts of this CreateExadataInfrastructureDetails.
        :type: list[oci.database.models.ExadataInfrastructureContact]
        """
        self._contacts = contacts

    @property
    def maintenance_window(self):
        """
        Gets the maintenance_window of this CreateExadataInfrastructureDetails.

        :return: The maintenance_window of this CreateExadataInfrastructureDetails.
        :rtype: oci.database.models.MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """
        Sets the maintenance_window of this CreateExadataInfrastructureDetails.

        :param maintenance_window: The maintenance_window of this CreateExadataInfrastructureDetails.
        :type: oci.database.models.MaintenanceWindow
        """
        self._maintenance_window = maintenance_window

    @property
    def storage_count(self):
        """
        Gets the storage_count of this CreateExadataInfrastructureDetails.
        The number of storage servers for the Exadata infrastructure.


        :return: The storage_count of this CreateExadataInfrastructureDetails.
        :rtype: int
        """
        return self._storage_count

    @storage_count.setter
    def storage_count(self, storage_count):
        """
        Sets the storage_count of this CreateExadataInfrastructureDetails.
        The number of storage servers for the Exadata infrastructure.


        :param storage_count: The storage_count of this CreateExadataInfrastructureDetails.
        :type: int
        """
        self._storage_count = storage_count

    @property
    def compute_count(self):
        """
        Gets the compute_count of this CreateExadataInfrastructureDetails.
        The number of compute servers for the Exadata infrastructure.


        :return: The compute_count of this CreateExadataInfrastructureDetails.
        :rtype: int
        """
        return self._compute_count

    @compute_count.setter
    def compute_count(self, compute_count):
        """
        Sets the compute_count of this CreateExadataInfrastructureDetails.
        The number of compute servers for the Exadata infrastructure.


        :param compute_count: The compute_count of this CreateExadataInfrastructureDetails.
        :type: int
        """
        self._compute_count = compute_count

    @property
    def dns_server(self):
        """
        **[Required]** Gets the dns_server of this CreateExadataInfrastructureDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :return: The dns_server of this CreateExadataInfrastructureDetails.
        :rtype: list[str]
        """
        return self._dns_server

    @dns_server.setter
    def dns_server(self, dns_server):
        """
        Sets the dns_server of this CreateExadataInfrastructureDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :param dns_server: The dns_server of this CreateExadataInfrastructureDetails.
        :type: list[str]
        """
        self._dns_server = dns_server

    @property
    def ntp_server(self):
        """
        **[Required]** Gets the ntp_server of this CreateExadataInfrastructureDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :return: The ntp_server of this CreateExadataInfrastructureDetails.
        :rtype: list[str]
        """
        return self._ntp_server

    @ntp_server.setter
    def ntp_server(self, ntp_server):
        """
        Sets the ntp_server of this CreateExadataInfrastructureDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :param ntp_server: The ntp_server of this CreateExadataInfrastructureDetails.
        :type: list[str]
        """
        self._ntp_server = ntp_server

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateExadataInfrastructureDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateExadataInfrastructureDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateExadataInfrastructureDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateExadataInfrastructureDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .projection_rule import ProjectionRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NamePatternRule(ProjectionRule):
    """
    This rule projects fields by a name pattern, for example it may start with STR_ or end with _DATE. This is defined using a regular expression.
    """

    #: A constant which can be used with the matching_strategy property of a NamePatternRule.
    #: This constant has a value of "NAME_OR_TAGS"
    MATCHING_STRATEGY_NAME_OR_TAGS = "NAME_OR_TAGS"

    #: A constant which can be used with the matching_strategy property of a NamePatternRule.
    #: This constant has a value of "TAGS_ONLY"
    MATCHING_STRATEGY_TAGS_ONLY = "TAGS_ONLY"

    #: A constant which can be used with the matching_strategy property of a NamePatternRule.
    #: This constant has a value of "NAME_ONLY"
    MATCHING_STRATEGY_NAME_ONLY = "NAME_ONLY"

    #: A constant which can be used with the rule_type property of a NamePatternRule.
    #: This constant has a value of "INCLUDE"
    RULE_TYPE_INCLUDE = "INCLUDE"

    #: A constant which can be used with the rule_type property of a NamePatternRule.
    #: This constant has a value of "EXCLUDE"
    RULE_TYPE_EXCLUDE = "EXCLUDE"

    def __init__(self, **kwargs):
        """
        Initializes a new NamePatternRule object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.NamePatternRule.model_type` attribute
        of this class is ``NAME_PATTERN_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this NamePatternRule.
            Allowed values for this property are: "NAME_PATTERN_RULE", "TYPE_LIST_RULE", "NAME_LIST_RULE", "TYPED_NAME_PATTERN_RULE", "RENAME_RULE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this NamePatternRule.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this NamePatternRule.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this NamePatternRule.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param is_java_regex_syntax:
            The value to assign to the is_java_regex_syntax property of this NamePatternRule.
        :type is_java_regex_syntax: bool

        :param config_values:
            The value to assign to the config_values property of this NamePatternRule.
        :type config_values: oci.data_integration.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this NamePatternRule.
        :type object_status: int

        :param description:
            The value to assign to the description property of this NamePatternRule.
        :type description: str

        :param is_skip_remaining_rules_on_match:
            The value to assign to the is_skip_remaining_rules_on_match property of this NamePatternRule.
        :type is_skip_remaining_rules_on_match: bool

        :param scope:
            The value to assign to the scope property of this NamePatternRule.
        :type scope: object

        :param is_cascade:
            The value to assign to the is_cascade property of this NamePatternRule.
        :type is_cascade: bool

        :param matching_strategy:
            The value to assign to the matching_strategy property of this NamePatternRule.
            Allowed values for this property are: "NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type matching_strategy: str

        :param is_case_sensitive:
            The value to assign to the is_case_sensitive property of this NamePatternRule.
        :type is_case_sensitive: bool

        :param rule_type:
            The value to assign to the rule_type property of this NamePatternRule.
            Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rule_type: str

        :param pattern:
            The value to assign to the pattern property of this NamePatternRule.
        :type pattern: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'is_java_regex_syntax': 'bool',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'description': 'str',
            'is_skip_remaining_rules_on_match': 'bool',
            'scope': 'object',
            'is_cascade': 'bool',
            'matching_strategy': 'str',
            'is_case_sensitive': 'bool',
            'rule_type': 'str',
            'pattern': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'is_java_regex_syntax': 'isJavaRegexSyntax',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'description': 'description',
            'is_skip_remaining_rules_on_match': 'isSkipRemainingRulesOnMatch',
            'scope': 'scope',
            'is_cascade': 'isCascade',
            'matching_strategy': 'matchingStrategy',
            'is_case_sensitive': 'isCaseSensitive',
            'rule_type': 'ruleType',
            'pattern': 'pattern'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._is_java_regex_syntax = None
        self._config_values = None
        self._object_status = None
        self._description = None
        self._is_skip_remaining_rules_on_match = None
        self._scope = None
        self._is_cascade = None
        self._matching_strategy = None
        self._is_case_sensitive = None
        self._rule_type = None
        self._pattern = None
        self._model_type = 'NAME_PATTERN_RULE'

    @property
    def is_skip_remaining_rules_on_match(self):
        """
        Gets the is_skip_remaining_rules_on_match of this NamePatternRule.
        Specifies whether to skip remaining rules when a match is found.


        :return: The is_skip_remaining_rules_on_match of this NamePatternRule.
        :rtype: bool
        """
        return self._is_skip_remaining_rules_on_match

    @is_skip_remaining_rules_on_match.setter
    def is_skip_remaining_rules_on_match(self, is_skip_remaining_rules_on_match):
        """
        Sets the is_skip_remaining_rules_on_match of this NamePatternRule.
        Specifies whether to skip remaining rules when a match is found.


        :param is_skip_remaining_rules_on_match: The is_skip_remaining_rules_on_match of this NamePatternRule.
        :type: bool
        """
        self._is_skip_remaining_rules_on_match = is_skip_remaining_rules_on_match

    @property
    def scope(self):
        """
        Gets the scope of this NamePatternRule.
        Reference to a typed object. This can be either a key value to an object within the document, a shall referenced to a `TypedObject`, or a full `TypedObject` definition.


        :return: The scope of this NamePatternRule.
        :rtype: object
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this NamePatternRule.
        Reference to a typed object. This can be either a key value to an object within the document, a shall referenced to a `TypedObject`, or a full `TypedObject` definition.


        :param scope: The scope of this NamePatternRule.
        :type: object
        """
        self._scope = scope

    @property
    def is_cascade(self):
        """
        Gets the is_cascade of this NamePatternRule.
        Specifies whether to cascade or not.


        :return: The is_cascade of this NamePatternRule.
        :rtype: bool
        """
        return self._is_cascade

    @is_cascade.setter
    def is_cascade(self, is_cascade):
        """
        Sets the is_cascade of this NamePatternRule.
        Specifies whether to cascade or not.


        :param is_cascade: The is_cascade of this NamePatternRule.
        :type: bool
        """
        self._is_cascade = is_cascade

    @property
    def matching_strategy(self):
        """
        Gets the matching_strategy of this NamePatternRule.
        The pattern matching strategy.

        Allowed values for this property are: "NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The matching_strategy of this NamePatternRule.
        :rtype: str
        """
        return self._matching_strategy

    @matching_strategy.setter
    def matching_strategy(self, matching_strategy):
        """
        Sets the matching_strategy of this NamePatternRule.
        The pattern matching strategy.


        :param matching_strategy: The matching_strategy of this NamePatternRule.
        :type: str
        """
        allowed_values = ["NAME_OR_TAGS", "TAGS_ONLY", "NAME_ONLY"]
        if not value_allowed_none_or_none_sentinel(matching_strategy, allowed_values):
            matching_strategy = 'UNKNOWN_ENUM_VALUE'
        self._matching_strategy = matching_strategy

    @property
    def is_case_sensitive(self):
        """
        Gets the is_case_sensitive of this NamePatternRule.
        Specifies if the rule is case sensitive.


        :return: The is_case_sensitive of this NamePatternRule.
        :rtype: bool
        """
        return self._is_case_sensitive

    @is_case_sensitive.setter
    def is_case_sensitive(self, is_case_sensitive):
        """
        Sets the is_case_sensitive of this NamePatternRule.
        Specifies if the rule is case sensitive.


        :param is_case_sensitive: The is_case_sensitive of this NamePatternRule.
        :type: bool
        """
        self._is_case_sensitive = is_case_sensitive

    @property
    def rule_type(self):
        """
        Gets the rule_type of this NamePatternRule.
        The rule type.

        Allowed values for this property are: "INCLUDE", "EXCLUDE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rule_type of this NamePatternRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this NamePatternRule.
        The rule type.


        :param rule_type: The rule_type of this NamePatternRule.
        :type: str
        """
        allowed_values = ["INCLUDE", "EXCLUDE"]
        if not value_allowed_none_or_none_sentinel(rule_type, allowed_values):
            rule_type = 'UNKNOWN_ENUM_VALUE'
        self._rule_type = rule_type

    @property
    def pattern(self):
        """
        Gets the pattern of this NamePatternRule.
        The rule pattern.


        :return: The pattern of this NamePatternRule.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this NamePatternRule.
        The rule pattern.


        :param pattern: The pattern of this NamePatternRule.
        :type: str
        """
        self._pattern = pattern

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityRule(object):
    """
    A security rule is one of the items in a :class:`NetworkSecurityGroup`.
    It is a virtual firewall rule for the VNICs in the network security group. A rule can be for
    either inbound (`direction`= INGRESS) or outbound (`direction`= EGRESS) IP packets.
    """

    #: A constant which can be used with the destination_type property of a SecurityRule.
    #: This constant has a value of "CIDR_BLOCK"
    DESTINATION_TYPE_CIDR_BLOCK = "CIDR_BLOCK"

    #: A constant which can be used with the destination_type property of a SecurityRule.
    #: This constant has a value of "SERVICE_CIDR_BLOCK"
    DESTINATION_TYPE_SERVICE_CIDR_BLOCK = "SERVICE_CIDR_BLOCK"

    #: A constant which can be used with the destination_type property of a SecurityRule.
    #: This constant has a value of "NETWORK_SECURITY_GROUP"
    DESTINATION_TYPE_NETWORK_SECURITY_GROUP = "NETWORK_SECURITY_GROUP"

    #: A constant which can be used with the direction property of a SecurityRule.
    #: This constant has a value of "EGRESS"
    DIRECTION_EGRESS = "EGRESS"

    #: A constant which can be used with the direction property of a SecurityRule.
    #: This constant has a value of "INGRESS"
    DIRECTION_INGRESS = "INGRESS"

    #: A constant which can be used with the source_type property of a SecurityRule.
    #: This constant has a value of "CIDR_BLOCK"
    SOURCE_TYPE_CIDR_BLOCK = "CIDR_BLOCK"

    #: A constant which can be used with the source_type property of a SecurityRule.
    #: This constant has a value of "SERVICE_CIDR_BLOCK"
    SOURCE_TYPE_SERVICE_CIDR_BLOCK = "SERVICE_CIDR_BLOCK"

    #: A constant which can be used with the source_type property of a SecurityRule.
    #: This constant has a value of "NETWORK_SECURITY_GROUP"
    SOURCE_TYPE_NETWORK_SECURITY_GROUP = "NETWORK_SECURITY_GROUP"

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this SecurityRule.
        :type description: str

        :param destination:
            The value to assign to the destination property of this SecurityRule.
        :type destination: str

        :param destination_type:
            The value to assign to the destination_type property of this SecurityRule.
            Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type destination_type: str

        :param direction:
            The value to assign to the direction property of this SecurityRule.
            Allowed values for this property are: "EGRESS", "INGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type direction: str

        :param icmp_options:
            The value to assign to the icmp_options property of this SecurityRule.
        :type icmp_options: oci.core.models.IcmpOptions

        :param id:
            The value to assign to the id property of this SecurityRule.
        :type id: str

        :param is_stateless:
            The value to assign to the is_stateless property of this SecurityRule.
        :type is_stateless: bool

        :param is_valid:
            The value to assign to the is_valid property of this SecurityRule.
        :type is_valid: bool

        :param protocol:
            The value to assign to the protocol property of this SecurityRule.
        :type protocol: str

        :param source:
            The value to assign to the source property of this SecurityRule.
        :type source: str

        :param source_type:
            The value to assign to the source_type property of this SecurityRule.
            Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_type: str

        :param tcp_options:
            The value to assign to the tcp_options property of this SecurityRule.
        :type tcp_options: oci.core.models.TcpOptions

        :param time_created:
            The value to assign to the time_created property of this SecurityRule.
        :type time_created: datetime

        :param udp_options:
            The value to assign to the udp_options property of this SecurityRule.
        :type udp_options: oci.core.models.UdpOptions

        """
        self.swagger_types = {
            'description': 'str',
            'destination': 'str',
            'destination_type': 'str',
            'direction': 'str',
            'icmp_options': 'IcmpOptions',
            'id': 'str',
            'is_stateless': 'bool',
            'is_valid': 'bool',
            'protocol': 'str',
            'source': 'str',
            'source_type': 'str',
            'tcp_options': 'TcpOptions',
            'time_created': 'datetime',
            'udp_options': 'UdpOptions'
        }

        self.attribute_map = {
            'description': 'description',
            'destination': 'destination',
            'destination_type': 'destinationType',
            'direction': 'direction',
            'icmp_options': 'icmpOptions',
            'id': 'id',
            'is_stateless': 'isStateless',
            'is_valid': 'isValid',
            'protocol': 'protocol',
            'source': 'source',
            'source_type': 'sourceType',
            'tcp_options': 'tcpOptions',
            'time_created': 'timeCreated',
            'udp_options': 'udpOptions'
        }

        self._description = None
        self._destination = None
        self._destination_type = None
        self._direction = None
        self._icmp_options = None
        self._id = None
        self._is_stateless = None
        self._is_valid = None
        self._protocol = None
        self._source = None
        self._source_type = None
        self._tcp_options = None
        self._time_created = None
        self._udp_options = None

    @property
    def description(self):
        """
        Gets the description of this SecurityRule.
        An optional description of your choice for the rule.


        :return: The description of this SecurityRule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SecurityRule.
        An optional description of your choice for the rule.


        :param description: The description of this SecurityRule.
        :type: str
        """
        self._description = description

    @property
    def destination(self):
        """
        Gets the destination of this SecurityRule.
        Conceptually, this is the range of IP addresses that a packet originating from the instance
        can go to.

        Allowed values:

          * An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
            IPv6 addressing is supported for all commercial and government regions.
            See `IPv6 Addresses`__.

          * The `cidrBlock` value for a :class:`Service`, if you're
            setting up a security rule for traffic destined for a particular `Service` through
            a service gateway. For example: `oci-phx-objectstorage`.

          * The OCID of a :class:`NetworkSecurityGroup` in the same
            VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
            traffic between VNICs in the same NSG.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The destination of this SecurityRule.
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """
        Sets the destination of this SecurityRule.
        Conceptually, this is the range of IP addresses that a packet originating from the instance
        can go to.

        Allowed values:

          * An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
            IPv6 addressing is supported for all commercial and government regions.
            See `IPv6 Addresses`__.

          * The `cidrBlock` value for a :class:`Service`, if you're
            setting up a security rule for traffic destined for a particular `Service` through
            a service gateway. For example: `oci-phx-objectstorage`.

          * The OCID of a :class:`NetworkSecurityGroup` in the same
            VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
            traffic between VNICs in the same NSG.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param destination: The destination of this SecurityRule.
        :type: str
        """
        self._destination = destination

    @property
    def destination_type(self):
        """
        Gets the destination_type of this SecurityRule.
        Type of destination for the rule. Required if `direction` = `EGRESS`.

        Allowed values:

          * `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.

          * `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic destined for a
            particular `Service` through a service gateway).

          * `NETWORK_SECURITY_GROUP`: If the rule's `destination` is the OCID of a
            :class:`NetworkSecurityGroup`.

        Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The destination_type of this SecurityRule.
        :rtype: str
        """
        return self._destination_type

    @destination_type.setter
    def destination_type(self, destination_type):
        """
        Sets the destination_type of this SecurityRule.
        Type of destination for the rule. Required if `direction` = `EGRESS`.

        Allowed values:

          * `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.

          * `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic destined for a
            particular `Service` through a service gateway).

          * `NETWORK_SECURITY_GROUP`: If the rule's `destination` is the OCID of a
            :class:`NetworkSecurityGroup`.


        :param destination_type: The destination_type of this SecurityRule.
        :type: str
        """
        allowed_values = ["CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP"]
        if not value_allowed_none_or_none_sentinel(destination_type, allowed_values):
            destination_type = 'UNKNOWN_ENUM_VALUE'
        self._destination_type = destination_type

    @property
    def direction(self):
        """
        **[Required]** Gets the direction of this SecurityRule.
        Direction of the security rule. Set to `EGRESS` for rules to allow outbound IP packets,
        or `INGRESS` for rules to allow inbound IP packets.

        Allowed values for this property are: "EGRESS", "INGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The direction of this SecurityRule.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this SecurityRule.
        Direction of the security rule. Set to `EGRESS` for rules to allow outbound IP packets,
        or `INGRESS` for rules to allow inbound IP packets.


        :param direction: The direction of this SecurityRule.
        :type: str
        """
        allowed_values = ["EGRESS", "INGRESS"]
        if not value_allowed_none_or_none_sentinel(direction, allowed_values):
            direction = 'UNKNOWN_ENUM_VALUE'
        self._direction = direction

    @property
    def icmp_options(self):
        """
        Gets the icmp_options of this SecurityRule.

        :return: The icmp_options of this SecurityRule.
        :rtype: oci.core.models.IcmpOptions
        """
        return self._icmp_options

    @icmp_options.setter
    def icmp_options(self, icmp_options):
        """
        Sets the icmp_options of this SecurityRule.

        :param icmp_options: The icmp_options of this SecurityRule.
        :type: oci.core.models.IcmpOptions
        """
        self._icmp_options = icmp_options

    @property
    def id(self):
        """
        Gets the id of this SecurityRule.
        An Oracle-assigned identifier for the security rule. You specify this ID when you want to
        update or delete the rule.

        Example: `04ABEC`


        :return: The id of this SecurityRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SecurityRule.
        An Oracle-assigned identifier for the security rule. You specify this ID when you want to
        update or delete the rule.

        Example: `04ABEC`


        :param id: The id of this SecurityRule.
        :type: str
        """
        self._id = id

    @property
    def is_stateless(self):
        """
        Gets the is_stateless of this SecurityRule.
        A stateless rule allows traffic in one direction. Remember to add a corresponding
        stateless rule in the other direction if you need to support bidirectional traffic. For
        example, if egress traffic allows TCP destination port 80, there should be an ingress
        rule to allow TCP source port 80. Defaults to false, which means the rule is stateful
        and a corresponding rule is not necessary for bidirectional traffic.


        :return: The is_stateless of this SecurityRule.
        :rtype: bool
        """
        return self._is_stateless

    @is_stateless.setter
    def is_stateless(self, is_stateless):
        """
        Sets the is_stateless of this SecurityRule.
        A stateless rule allows traffic in one direction. Remember to add a corresponding
        stateless rule in the other direction if you need to support bidirectional traffic. For
        example, if egress traffic allows TCP destination port 80, there should be an ingress
        rule to allow TCP source port 80. Defaults to false, which means the rule is stateful
        and a corresponding rule is not necessary for bidirectional traffic.


        :param is_stateless: The is_stateless of this SecurityRule.
        :type: bool
        """
        self._is_stateless = is_stateless

    @property
    def is_valid(self):
        """
        Gets the is_valid of this SecurityRule.
        Whether the rule is valid. The value is `True` when the rule is first created. If
        the rule's `source` or `destination` is a network security group, the value changes to
        `False` if that network security group is deleted.


        :return: The is_valid of this SecurityRule.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """
        Sets the is_valid of this SecurityRule.
        Whether the rule is valid. The value is `True` when the rule is first created. If
        the rule's `source` or `destination` is a network security group, the value changes to
        `False` if that network security group is deleted.


        :param is_valid: The is_valid of this SecurityRule.
        :type: bool
        """
        self._is_valid = is_valid

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this SecurityRule.
        The transport protocol. Specify either `all` or an IPv4 protocol number as
        defined in
        `Protocol Numbers`__.
        Options are supported only for ICMP (\"1\"), TCP (\"6\"), UDP (\"17\"), and ICMPv6 (\"58\").

        __ http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml


        :return: The protocol of this SecurityRule.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this SecurityRule.
        The transport protocol. Specify either `all` or an IPv4 protocol number as
        defined in
        `Protocol Numbers`__.
        Options are supported only for ICMP (\"1\"), TCP (\"6\"), UDP (\"17\"), and ICMPv6 (\"58\").

        __ http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml


        :param protocol: The protocol of this SecurityRule.
        :type: str
        """
        self._protocol = protocol

    @property
    def source(self):
        """
        Gets the source of this SecurityRule.
        Conceptually, this is the range of IP addresses that a packet coming into the instance
        can come from.

        Allowed values:

          * An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
            IPv6 addressing is supported for all commercial and government regions.
            See `IPv6 Addresses`__.

          * The `cidrBlock` value for a :class:`Service`, if you're
            setting up a security rule for traffic coming from a particular `Service` through
            a service gateway. For example: `oci-phx-objectstorage`.

          * The OCID of a :class:`NetworkSecurityGroup` in the same
            VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
            traffic between VNICs in the same NSG.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The source of this SecurityRule.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this SecurityRule.
        Conceptually, this is the range of IP addresses that a packet coming into the instance
        can come from.

        Allowed values:

          * An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
            IPv6 addressing is supported for all commercial and government regions.
            See `IPv6 Addresses`__.

          * The `cidrBlock` value for a :class:`Service`, if you're
            setting up a security rule for traffic coming from a particular `Service` through
            a service gateway. For example: `oci-phx-objectstorage`.

          * The OCID of a :class:`NetworkSecurityGroup` in the same
            VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
            traffic between VNICs in the same NSG.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param source: The source of this SecurityRule.
        :type: str
        """
        self._source = source

    @property
    def source_type(self):
        """
        Gets the source_type of this SecurityRule.
        Type of source for the rule. Required if `direction` = `INGRESS`.

          * `CIDR_BLOCK`: If the rule's `source` is an IP address range in CIDR notation.

          * `SERVICE_CIDR_BLOCK`: If the rule's `source` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic coming from a
            particular `Service` through a service gateway).

          * `NETWORK_SECURITY_GROUP`: If the rule's `source` is the OCID of a
            :class:`NetworkSecurityGroup`.

        Allowed values for this property are: "CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_type of this SecurityRule.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this SecurityRule.
        Type of source for the rule. Required if `direction` = `INGRESS`.

          * `CIDR_BLOCK`: If the rule's `source` is an IP address range in CIDR notation.

          * `SERVICE_CIDR_BLOCK`: If the rule's `source` is the `cidrBlock` value for a
            :class:`Service` (the rule is for traffic coming from a
            particular `Service` through a service gateway).

          * `NETWORK_SECURITY_GROUP`: If the rule's `source` is the OCID of a
            :class:`NetworkSecurityGroup`.


        :param source_type: The source_type of this SecurityRule.
        :type: str
        """
        allowed_values = ["CIDR_BLOCK", "SERVICE_CIDR_BLOCK", "NETWORK_SECURITY_GROUP"]
        if not value_allowed_none_or_none_sentinel(source_type, allowed_values):
            source_type = 'UNKNOWN_ENUM_VALUE'
        self._source_type = source_type

    @property
    def tcp_options(self):
        """
        Gets the tcp_options of this SecurityRule.

        :return: The tcp_options of this SecurityRule.
        :rtype: oci.core.models.TcpOptions
        """
        return self._tcp_options

    @tcp_options.setter
    def tcp_options(self, tcp_options):
        """
        Sets the tcp_options of this SecurityRule.

        :param tcp_options: The tcp_options of this SecurityRule.
        :type: oci.core.models.TcpOptions
        """
        self._tcp_options = tcp_options

    @property
    def time_created(self):
        """
        Gets the time_created of this SecurityRule.
        The date and time the security rule was created. Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SecurityRule.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SecurityRule.
        The date and time the security rule was created. Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SecurityRule.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def udp_options(self):
        """
        Gets the udp_options of this SecurityRule.

        :return: The udp_options of this SecurityRule.
        :rtype: oci.core.models.UdpOptions
        """
        return self._udp_options

    @udp_options.setter
    def udp_options(self, udp_options):
        """
        Sets the udp_options of this SecurityRule.

        :param udp_options: The udp_options of this SecurityRule.
        :type: oci.core.models.UdpOptions
        """
        self._udp_options = udp_options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreationSource(object):
    """
    Details for auto-created entity.
    """

    #: A constant which can be used with the type property of a CreationSource.
    #: This constant has a value of "EM_BRIDGE"
    TYPE_EM_BRIDGE = "EM_BRIDGE"

    #: A constant which can be used with the type property of a CreationSource.
    #: This constant has a value of "SERVICE_CONNECTOR_HUB"
    TYPE_SERVICE_CONNECTOR_HUB = "SERVICE_CONNECTOR_HUB"

    #: A constant which can be used with the type property of a CreationSource.
    #: This constant has a value of "NONE"
    TYPE_NONE = "NONE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreationSource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this CreationSource.
            Allowed values for this property are: "EM_BRIDGE", "SERVICE_CONNECTOR_HUB", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param details:
            The value to assign to the details property of this CreationSource.
        :type details: str

        """
        self.swagger_types = {
            'type': 'str',
            'details': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'details': 'details'
        }

        self._type = None
        self._details = None

    @property
    def type(self):
        """
        Gets the type of this CreationSource.
        Source that auto-created the entity.

        Allowed values for this property are: "EM_BRIDGE", "SERVICE_CONNECTOR_HUB", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this CreationSource.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreationSource.
        Source that auto-created the entity.


        :param type: The type of this CreationSource.
        :type: str
        """
        allowed_values = ["EM_BRIDGE", "SERVICE_CONNECTOR_HUB", "NONE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def details(self):
        """
        Gets the details of this CreationSource.
        This will provide additional details for source of auto-creation. For example, if entity is auto-created
        by enterprise manager bridge, this field provides additional detail on enterprise manager that contributed
        to the entity auto-creation.


        :return: The details of this CreationSource.
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this CreationSource.
        This will provide additional details for source of auto-creation. For example, if entity is auto-created
        by enterprise manager bridge, this field provides additional detail on enterprise manager that contributed
        to the entity auto-creation.


        :param details: The details of this CreationSource.
        :type: str
        """
        self._details = details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostPortScanResultOpenPort(object):
    """
    An open port found in a host port scan
    """

    #: A constant which can be used with the severity property of a HostPortScanResultOpenPort.
    #: This constant has a value of "NONE"
    SEVERITY_NONE = "NONE"

    #: A constant which can be used with the severity property of a HostPortScanResultOpenPort.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a HostPortScanResultOpenPort.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a HostPortScanResultOpenPort.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a HostPortScanResultOpenPort.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    def __init__(self, **kwargs):
        """
        Initializes a new HostPortScanResultOpenPort object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param port:
            The value to assign to the port property of this HostPortScanResultOpenPort.
        :type port: int

        :param protocol:
            The value to assign to the protocol property of this HostPortScanResultOpenPort.
        :type protocol: str

        :param ip_address:
            The value to assign to the ip_address property of this HostPortScanResultOpenPort.
        :type ip_address: str

        :param vnic_id:
            The value to assign to the vnic_id property of this HostPortScanResultOpenPort.
        :type vnic_id: str

        :param service:
            The value to assign to the service property of this HostPortScanResultOpenPort.
        :type service: str

        :param severity:
            The value to assign to the severity property of this HostPortScanResultOpenPort.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        """
        self.swagger_types = {
            'port': 'int',
            'protocol': 'str',
            'ip_address': 'str',
            'vnic_id': 'str',
            'service': 'str',
            'severity': 'str'
        }

        self.attribute_map = {
            'port': 'port',
            'protocol': 'protocol',
            'ip_address': 'ipAddress',
            'vnic_id': 'vnicId',
            'service': 'service',
            'severity': 'severity'
        }

        self._port = None
        self._protocol = None
        self._ip_address = None
        self._vnic_id = None
        self._service = None
        self._severity = None

    @property
    def port(self):
        """
        **[Required]** Gets the port of this HostPortScanResultOpenPort.
        Open port


        :return: The port of this HostPortScanResultOpenPort.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this HostPortScanResultOpenPort.
        Open port


        :param port: The port of this HostPortScanResultOpenPort.
        :type: int
        """
        self._port = port

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this HostPortScanResultOpenPort.
        Protocol of the open port


        :return: The protocol of this HostPortScanResultOpenPort.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this HostPortScanResultOpenPort.
        Protocol of the open port


        :param protocol: The protocol of this HostPortScanResultOpenPort.
        :type: str
        """
        self._protocol = protocol

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this HostPortScanResultOpenPort.
        IP Address open port was found on


        :return: The ip_address of this HostPortScanResultOpenPort.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this HostPortScanResultOpenPort.
        IP Address open port was found on


        :param ip_address: The ip_address of this HostPortScanResultOpenPort.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def vnic_id(self):
        """
        **[Required]** Gets the vnic_id of this HostPortScanResultOpenPort.
        ID of the attached VNIC that exposed the IP Address scanned


        :return: The vnic_id of this HostPortScanResultOpenPort.
        :rtype: str
        """
        return self._vnic_id

    @vnic_id.setter
    def vnic_id(self, vnic_id):
        """
        Sets the vnic_id of this HostPortScanResultOpenPort.
        ID of the attached VNIC that exposed the IP Address scanned


        :param vnic_id: The vnic_id of this HostPortScanResultOpenPort.
        :type: str
        """
        self._vnic_id = vnic_id

    @property
    def service(self):
        """
        Gets the service of this HostPortScanResultOpenPort.
        Service running on the port (if detected)


        :return: The service of this HostPortScanResultOpenPort.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this HostPortScanResultOpenPort.
        Service running on the port (if detected)


        :param service: The service of this HostPortScanResultOpenPort.
        :type: str
        """
        self._service = service

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this HostPortScanResultOpenPort.
        Problem severity

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this HostPortScanResultOpenPort.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this HostPortScanResultOpenPort.
        Problem severity


        :param severity: The severity of this HostPortScanResultOpenPort.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateNodePoolNodeConfigDetails(object):
    """
    The size and placement configuration of nodes in the node pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateNodePoolNodeConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param size:
            The value to assign to the size property of this CreateNodePoolNodeConfigDetails.
        :type size: int

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateNodePoolNodeConfigDetails.
        :type nsg_ids: list[str]

        :param placement_configs:
            The value to assign to the placement_configs property of this CreateNodePoolNodeConfigDetails.
        :type placement_configs: list[oci.container_engine.models.NodePoolPlacementConfigDetails]

        """
        self.swagger_types = {
            'size': 'int',
            'nsg_ids': 'list[str]',
            'placement_configs': 'list[NodePoolPlacementConfigDetails]'
        }

        self.attribute_map = {
            'size': 'size',
            'nsg_ids': 'nsgIds',
            'placement_configs': 'placementConfigs'
        }

        self._size = None
        self._nsg_ids = None
        self._placement_configs = None

    @property
    def size(self):
        """
        **[Required]** Gets the size of this CreateNodePoolNodeConfigDetails.
        The number of nodes that should be in the node pool.


        :return: The size of this CreateNodePoolNodeConfigDetails.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this CreateNodePoolNodeConfigDetails.
        The number of nodes that should be in the node pool.


        :param size: The size of this CreateNodePoolNodeConfigDetails.
        :type: int
        """
        self._size = size

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateNodePoolNodeConfigDetails.
        The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see :class:`NetworkSecurityGroup`.


        :return: The nsg_ids of this CreateNodePoolNodeConfigDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateNodePoolNodeConfigDetails.
        The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see :class:`NetworkSecurityGroup`.


        :param nsg_ids: The nsg_ids of this CreateNodePoolNodeConfigDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def placement_configs(self):
        """
        **[Required]** Gets the placement_configs of this CreateNodePoolNodeConfigDetails.
        The placement configurations for the node pool. Provide one placement
        configuration for each availability domain in which you intend to launch a node.

        To use the node pool with a regional subnet, provide a placement configuration for
        each availability domain, and include the regional subnet in each placement
        configuration.


        :return: The placement_configs of this CreateNodePoolNodeConfigDetails.
        :rtype: list[oci.container_engine.models.NodePoolPlacementConfigDetails]
        """
        return self._placement_configs

    @placement_configs.setter
    def placement_configs(self, placement_configs):
        """
        Sets the placement_configs of this CreateNodePoolNodeConfigDetails.
        The placement configurations for the node pool. Provide one placement
        configuration for each availability domain in which you intend to launch a node.

        To use the node pool with a regional subnet, provide a placement configuration for
        each availability domain, and include the regional subnet in each placement
        configuration.


        :param placement_configs: The placement_configs of this CreateNodePoolNodeConfigDetails.
        :type: list[oci.container_engine.models.NodePoolPlacementConfigDetails]
        """
        self._placement_configs = placement_configs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import io

# Currently Python HTTP client sends data to the server in blocksize
# of 8192 bytes. This causes a lot of reads and execution of CPU bound
# code between sends. This hampers the advantages of parallel threads
# and hence throughput for multipart uploads drops beyond 3-4 threads.
# Adding a force read size of 64KB
FORCED_READ_SIZE = 64 * 1024  # 64KB


class BufferedPartReader(io.IOBase):
    def __init__(self, file_object, start, size, forced_read_size=FORCED_READ_SIZE):
        """
        Build an object that will act like a BufferedReader object,
        but constrained to a predetermined part of the file_object.

        :param file_object: A file opened for reading in binary mode.
        :param start: Start of the part within the file_object
        :param size: Ideal size of the part.  This will be set
                     to the number of bytes remaining in the
                     file if there aren't enough bytes remaining.
        """
        self.file = file_object
        self.bytes_read = 0
        self.start = start
        self.forced_read_size = forced_read_size

        # Seek to the end of the file to see how many bytes remain
        # from the start of the part.
        self.file.seek(0, io.SEEK_END)
        self.size = min(self.file.tell() - self.start, size)

        # Reset the pointer to the start of the part.
        self.file.seek(start, io.SEEK_SET)

    def seek(self, offset, whence=io.SEEK_SET):
        """
        Seek within the part.  This is similar to the standard seek, except
        that io.SEEK_SET is the start of the part and io.SEEK_END is the
        end of the part.

        :param offset: Offset in bytes from location determined by the whence value
        :param whence: io.SEEK_END and io.SEEK_SET are supported.
        """
        if whence == io.SEEK_END:
            self.file.seek(self.start + self.size + offset, io.SEEK_SET)
        elif whence == io.SEEK_SET:
            self.file.seek(self.start + offset, io.SEEK_SET)
        else:
            raise RuntimeError("Unhandled whence value: {}".format(whence))

    def tell(self):
        """
        Determine where the file pointer is relative to the start of the part.

        :return: Relative position in the part
        """
        return self.file.tell() - self.start

    def read(self, n=-1):
        """
        Read data from the part, but make the end of the part look like
        the end of file has been reached.

        :param n: Bytes to read
        :return: Memoryview of the bytes read from the part
        """
        # Use bytearray of forced_read_size for any n less than forced_read_size
        buf = bytearray(n) if n == -1 or n == 0 or n > self.forced_read_size else bytearray(self.forced_read_size)
        read = 0
        if self.bytes_read < self.size:
            read = self.file.readinto(buf)
            self.bytes_read += read
            # Check to see if the current buffer contains bytes that come from
            # the next part.
            if self.bytes_read > self.size:
                # Subtract the number of excess bytes from the bytes read.
                read -= self.bytes_read - self.size

        # Wrap the bytearray in a memoryview because the Python 2.7 implementation
        # of Requests needs a memoryview, buffer or byte string.
        return memoryview(buf[:read])



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TlsConfig(object):
    """
    The details required to establish a TLS enabled connection.
    """

    #: A constant which can be used with the status property of a TlsConfig.
    #: This constant has a value of "ENABLED"
    STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the status property of a TlsConfig.
    #: This constant has a value of "DISABLED"
    STATUS_DISABLED = "DISABLED"

    #: A constant which can be used with the certificate_store_type property of a TlsConfig.
    #: This constant has a value of "JKS"
    CERTIFICATE_STORE_TYPE_JKS = "JKS"

    def __init__(self, **kwargs):
        """
        Initializes a new TlsConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this TlsConfig.
            Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param certificate_store_type:
            The value to assign to the certificate_store_type property of this TlsConfig.
            Allowed values for this property are: "JKS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type certificate_store_type: str

        :param store_password:
            The value to assign to the store_password property of this TlsConfig.
        :type store_password: str

        :param trust_store_content:
            The value to assign to the trust_store_content property of this TlsConfig.
        :type trust_store_content: str

        :param key_store_content:
            The value to assign to the key_store_content property of this TlsConfig.
        :type key_store_content: str

        """
        self.swagger_types = {
            'status': 'str',
            'certificate_store_type': 'str',
            'store_password': 'str',
            'trust_store_content': 'str',
            'key_store_content': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'certificate_store_type': 'certificateStoreType',
            'store_password': 'storePassword',
            'trust_store_content': 'trustStoreContent',
            'key_store_content': 'keyStoreContent'
        }

        self._status = None
        self._certificate_store_type = None
        self._store_password = None
        self._trust_store_content = None
        self._key_store_content = None

    @property
    def status(self):
        """
        **[Required]** Gets the status of this TlsConfig.
        Status to represent whether the database connection is TLS enabled or not.

        Allowed values for this property are: "ENABLED", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this TlsConfig.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TlsConfig.
        Status to represent whether the database connection is TLS enabled or not.


        :param status: The status of this TlsConfig.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def certificate_store_type(self):
        """
        Gets the certificate_store_type of this TlsConfig.
        The format of the certificate store.

        Allowed values for this property are: "JKS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The certificate_store_type of this TlsConfig.
        :rtype: str
        """
        return self._certificate_store_type

    @certificate_store_type.setter
    def certificate_store_type(self, certificate_store_type):
        """
        Sets the certificate_store_type of this TlsConfig.
        The format of the certificate store.


        :param certificate_store_type: The certificate_store_type of this TlsConfig.
        :type: str
        """
        allowed_values = ["JKS"]
        if not value_allowed_none_or_none_sentinel(certificate_store_type, allowed_values):
            certificate_store_type = 'UNKNOWN_ENUM_VALUE'
        self._certificate_store_type = certificate_store_type

    @property
    def store_password(self):
        """
        Gets the store_password of this TlsConfig.
        The password to read the trust store and key store files, if they are password protected.


        :return: The store_password of this TlsConfig.
        :rtype: str
        """
        return self._store_password

    @store_password.setter
    def store_password(self, store_password):
        """
        Sets the store_password of this TlsConfig.
        The password to read the trust store and key store files, if they are password protected.


        :param store_password: The store_password of this TlsConfig.
        :type: str
        """
        self._store_password = store_password

    @property
    def trust_store_content(self):
        """
        Gets the trust_store_content of this TlsConfig.
        Base64 encoded string of trust store file content.


        :return: The trust_store_content of this TlsConfig.
        :rtype: str
        """
        return self._trust_store_content

    @trust_store_content.setter
    def trust_store_content(self, trust_store_content):
        """
        Sets the trust_store_content of this TlsConfig.
        Base64 encoded string of trust store file content.


        :param trust_store_content: The trust_store_content of this TlsConfig.
        :type: str
        """
        self._trust_store_content = trust_store_content

    @property
    def key_store_content(self):
        """
        Gets the key_store_content of this TlsConfig.
        Base64 encoded string of key store file content.


        :return: The key_store_content of this TlsConfig.
        :rtype: str
        """
        return self._key_store_content

    @key_store_content.setter
    def key_store_content(self, key_store_content):
        """
        Sets the key_store_content of this TlsConfig.
        Base64 encoded string of key store file content.


        :param key_store_content: The key_store_content of this TlsConfig.
        :type: str
        """
        self._key_store_content = key_store_content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source_details import SourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InternalSourceDetails(SourceDetails):
    """
    Details about the Oracle Cloud Infrastructure - Classic account, the source environment from which you want to migrate the application.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InternalSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.application_migration.models.InternalSourceDetails.type` attribute
        of this class is ``INTERNAL_COMPUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this InternalSourceDetails.
            Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE", "OCC", "OCIC_IDCS", "IMPORT"
        :type type: str

        :param account_name:
            The value to assign to the account_name property of this InternalSourceDetails.
        :type account_name: str

        """
        self.swagger_types = {
            'type': 'str',
            'account_name': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'account_name': 'accountName'
        }

        self._type = None
        self._account_name = None
        self._type = 'INTERNAL_COMPUTE'

    @property
    def account_name(self):
        """
        **[Required]** Gets the account_name of this InternalSourceDetails.
        The identity domain ID of your traditional Oracle Cloud Infrastructure - Classic account.


        :return: The account_name of this InternalSourceDetails.
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """
        Sets the account_name of this InternalSourceDetails.
        The identity domain ID of your traditional Oracle Cloud Infrastructure - Classic account.


        :param account_name: The account_name of this InternalSourceDetails.
        :type: str
        """
        self._account_name = account_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
